import { Component, Input, OnChanges, SimpleChanges } from '@angular/core';
import { formType } from '../../formType.enum';
import { profileFormStep } from '../../profile-form/profileFormStep.enum';
import { structureFormStep } from '../../structure-form/structureFormStep.enum';

@Component({
  selector: 'app-progress-bar',
  templateUrl: './progress-bar.component.html',
  styleUrls: ['./progress-bar.component.scss'],
})
export class ProgressBarComponent implements OnChanges {
  @Input() formType: formType;
  /** Number of current step */
  @Input({ required: true }) currentPage: number;
  /** Total number of steps */
  @Input({ required: true }) nbSteps: number;
  public progressStatus: number;
  public formTypeEnum = formType;
  // When working with numeric enums, divide the result by 2, because a reverse mapping is generated.
  public profileFormSteps = Object.keys(profileFormStep).length / 2;
  public structureFormSteps = Object.keys(structureFormStep).length / 2;

  ngOnChanges(changes: SimpleChanges): void {
    if (changes.currentPage) {
      switch (this.formType) {
        case formType.profile: {
          this.progressStatus = ((this.currentPage + 1) / this.nbSteps) * 100;
          break;
        }
        case formType.structure: {
          this.progressStatus = ((this.currentPage + this.profileFormSteps + 1) / this.nbSteps) * 100;
          break;
        }
        case formType.personaloffer:
          this.progressStatus =
            ((this.currentPage + this.structureFormSteps + this.profileFormSteps + 1) / this.nbSteps) * 100;
          break;
        default:
          this.progressStatus = ((this.currentPage + 1) / this.nbSteps) * 100;
      }
    }
  }
}
